#include <cassert>
#include <iostream>
#include <fstream>
#include <string>
#include <sstream>
#include <vector>

using namespace std;

const int max_n = 1000;
const int max_x = 1000000;

const int AC = 0;
const int WA = 1;
const int PE = 2;
const int UE = 3;

long long gcd(long long a, long long b)
{
    if (!b) return a;
    while (b) {
        long long r = a % b;
        a = b;
        b = r;
    }
    return a;
}

int check(ifstream &f, int n, int x, string &comment, bool &can)
{
    int i, j;

    f >> i;
    if (!f) {
        comment = "couldn't read first integer";
        return PE;
    }
    if (i == -1) {
        can = false;
        return AC;
    }

    vector<int> p;
    p.push_back(0);
    p.push_back(i);
    for (i = 2; i <= n ;i++) {
        f >> j;
        if (!f) {
            comment = "couldn't read permutation";
            return PE;
        }
        p.push_back(j);
    }

    vector<int> vis(n+1);
    for (i = 1; i <= n; i++) {
        if (p[i] < 1 || p[i] > n) {
            comment = "illegal integer in permutation";
            return PE;
        }
        if (p[i] == i) {
            comment = "bad cycle (length 1)";
            return WA;
        }
        if (vis[p[i]]) {
            comment = "duplicate integer in permutation";
            return PE;
        }
        vis[p[i]] = 1;
    }

    vis = vector<int>(n+1);
    long long lcm = 1;
    for (i = 1; i <= n; i++) {
        if (vis[i]) continue;
        int j = i;
        int len = 0;
        while (!vis[j]) {
            len++;
            vis[j] = 1;
            j = p[j];
        }
        lcm = (lcm * len) / gcd(lcm, len);
    }
    if (lcm == x) {
        can = true;
        comment = "ok";
        return AC;
    } else {
        can = true;
        comment = "illegal LCM";
        return WA;
    }
}

int main(int argc, char* argv[])
{
    ifstream f_in(argv[1]);
    ifstream f_out(argv[2]);
    ifstream f_ans(argv[3]);

    int n, x;
    f_in >> n >> x;
    assert(2 <= n && n <= 1000);
    assert(2 <= x && x <= 1000000);

    string jury_comment, cont_comment;
    bool jury_can, cont_can;
    int jury_res = check(f_ans, n, x, jury_comment, jury_can);
    int cont_res = check(f_out, n, x, cont_comment, cont_can);

    if (jury_res != AC) {
        cout << "jury fail: " << jury_comment << endl;
        return UE;
    }

    if (cont_res != AC) {
        cout << cont_comment << endl;
        return cont_res;
    }

    if (jury_can && !cont_can) {
        cout << "contestant hasn't found an answer" << endl;
        return WA;
    }

    if (!jury_can && cont_can) {
        cout << "jury hasn't found an answer" << endl;
        return UE;
    }

    cout << "ok" << endl;
    return AC;
}
