#define DEBUG_OUTPUT

#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>

#include <algorithm>
#include <iostream>
#include <vector>

using namespace std;

const int MAXN = 1024;
const int MAXDIVS = 256;
const int MAXPRIMES = 7;

int n, x;
int k, x_primes[MAXPRIMES], x_degs[MAXPRIMES];
int q, divs[MAXDIVS], masks[MAXDIVS];
int vis[MAXN][1 << MAXPRIMES];
int vis1[MAXN];

void find_divisors(int i, int d)
{
    if (i == k) {
        if (d == 1) return;
        divs[q] = d;
        for (int j = 0; j < k; j++) {
            int ok = 1;
            int d1 = d;
            for (int sc = 0; sc < x_degs[j]; sc++) {
                if (d1 % x_primes[j]) {
                    ok = 0;
                    break;
                }
                d1 /= x_primes[j];
            }
            if (ok) masks[q] |= (1 << j);
        }
        q++;
        return;
    }

    int cur = 1;
    for (int j = 0; j <= x_degs[i]; j++) {
        find_divisors(i+1, d*cur);
        cur *= x_primes[i];
    }
}

bool solve_dp()
{
    int i, j;

    memset(vis, 0, sizeof(vis));
    vis[0][0] = 1;
    for (i = 0; i < n; i++) {
        for (j = 0; j < (1 << k); j++) {
            if (!vis[i][j]) continue;
            for (int sc = 0; sc < q; sc++) {
                int i1 = i + divs[sc];
                int j1 = j | masks[sc];
                if (i1 <= n) {
                    vis[i1][j1] = 1;
                }
            }
        }
    }

    return vis[n][(1 << k)-1];
}

bool solve_naive()
{
    int i, j;
    int sum = 0;
    for (i = 0; i < k; i++) {
        int cur = 1;
        for (j = 0; j < x_degs[i]; j++)
            cur *= x_primes[i];
        sum += cur;
    }

    if (sum > n) return false;

    int need = n-sum;
    memset(vis1, 0, sizeof(vis1));
    vis1[0] = 1;
    for (i = 0; i < need; i++) {
        if (!vis1[i]) continue;
        for (j = 0; j < k; j++) {
            if (i + x_primes[j] <= need)
                vis1[i + x_primes[j]] = 1;
        }
    }
    return vis1[need];
}

int main()
{
    freopen("input.txt" ,"rt", stdin); freopen("output.txt", "wt", stdout);

    int i, j;
    int trials = 1000000;

    int sc = 0;
    for (sc = 0; sc < trials; sc++) {
        n = rand() % 999 + 2;
        x = rand() % 999999 + 2;

        k = 0;
        int y = x;
        for (i = 2; i <= y; i++) {
            if (!(y % i)) {
                int deg = 0;
                while (!(y % i)) {
                    y /= i;
                    deg++;
                }
                x_primes[k] = i;
                x_degs[k] = deg;
                k++;
            }
        }

        q = 0;
        memset(masks, 0, sizeof(masks));
        find_divisors(0, 1);

        bool can_dp = solve_dp();
        bool can_naive = solve_naive();

        if (can_dp != can_naive) {
            cout << "can_dp = " << can_dp << ", can_naive = " << can_naive;
            cout << " n = " << n << ", x = " << x << endl;
        }

        if (!(sc % 1000))
            cout << sc << endl;
    }

    fclose(stdin); fclose(stdout);
    return 0;   
}
